# Changelog

## [3.0.0a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/3.0.0a1) (2024-11-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/2.4.4...3.0.0a1)

**Breaking changes:**

- deprecate!:backend client [\#295](https://github.com/OpenVoiceOS/OVOS-workshop/pull/295) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- Create skill.error.dialog nl-nl [\#294](https://github.com/OpenVoiceOS/OVOS-workshop/pull/294) ([timonvanhasselt](https://github.com/timonvanhasselt))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
